<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="vi" sourcelanguage="en">
<context>
    <name>AgendaPlug</name>
    <message>
        <location filename="../AgendaPlug.cpp" line="28"/>
        <source>Jump to today</source>
        <translation>Đi đến ngày hôm nay</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="29"/>
        <source>Jump to</source>
        <translation>Đi đến</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="30"/>
        <source>New event</source>
        <translation>Sự kiện mới</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.h" line="20"/>
        <source>Agenda</source>
        <translation>Tổ chức</translation>
    </message>
</context>
<context>
    <name>AlarmPickDialog</name>
    <message>
        <location filename="../AlarmPickDialog.ui" line="6"/>
        <source>Alarm</source>
        <translation>Báo thức</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="38"/>
        <source>In advance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="48"/>
        <source>Arbitrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="66"/>
        <source>Hours</source>
        <translation>Giờ</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="86"/>
        <source>Minutes</source>
        <translation>Phút</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="106"/>
        <source>Seconds</source>
        <translation>Giây</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="20"/>
        <source>Enable</source>
        <translation>Bật</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.cpp" line="15"/>
        <source>Done</source>
        <translation>Hoàn tất</translation>
    </message>
</context>
<context>
    <name>AlarmPickSelector</name>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="152"/>
        <source>None</source>
        <translation>Không có gì</translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="164"/>
        <source>Exact</source>
        <translation>Chính xác</translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="166"/>
        <source>%n hour(s) before</source>
        <translation>
            <numerusform>%n giờ trước khi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="167"/>
        <source>%n minute(s) before</source>
        <translation>
            <numerusform>%n phút trước khi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="168"/>
        <source>%n second(s) before</source>
        <translation>
            <numerusform>%n giây trước khi</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="170"/>
        <source>%1:%2:%3 before</source>
        <translation>%1:%2:%3 trước khi</translation>
    </message>
</context>
<context>
    <name>BirthdayEditDialog</name>
    <message>
        <location filename="../BirthdayEditDialog.ui" line="6"/>
        <source>Edit event</source>
        <translation>Chỉnh sửa sự kiện</translation>
    </message>
    <message>
        <location filename="../BirthdayEditDialog.ui" line="12"/>
        <source>Alarm</source>
        <translation>Báo thức</translation>
    </message>
</context>
<context>
    <name>ByDayWidget</name>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="37"/>
        <source>From beginning</source>
        <translation>Từ khi bắt đầu</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="38"/>
        <source>From end</source>
        <translation>Từ khi kết thúc</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="49"/>
        <source>By day of month</source>
        <translation>Theo ngày mỗi tháng</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="51"/>
        <source>By week of year</source>
        <translation>Theo tuần mỗi năm</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="53"/>
        <source>By day of year</source>
        <translation>Theo ngày mỗi ngày</translation>
    </message>
</context>
<context>
    <name>ByMonthWidget</name>
    <message>
        <location filename="../recurrence/ByMonthWidget.cpp" line="20"/>
        <source>By month</source>
        <translation>Theo tháng</translation>
    </message>
</context>
<context>
    <name>ByWeekdayWidget</name>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="21"/>
        <source>By day of week</source>
        <translation>Theo ngày trong tuần</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="55"/>
        <source>From beginning</source>
        <translation>Từ khi bắt đầu</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="56"/>
        <source>From end</source>
        <translation>Từ khi kết thúc</translation>
    </message>
</context>
<context>
    <name>CalendarEditDialog</name>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="52"/>
        <source>Edit calendar</source>
        <translation>Chỉnh sửa lịch</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="27"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="37"/>
        <source>Birthday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="53"/>
        <source>Color</source>
        <translation>Màu sắc</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="63"/>
        <source>Visible</source>
        <translation>Hiển thị</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="42"/>
        <source>Export</source>
        <translation>Xuất dữ liệu</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="43"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="90"/>
        <source>New calendar</source>
        <translation>Tạo lịch mới</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="94"/>
        <source>Save</source>
        <translation>Lưu lại</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="141"/>
        <location filename="../settings/CalendarEditDialog.cpp" line="166"/>
        <source>Error occurred</source>
        <translation>Xảy ra lỗi</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="175"/>
        <source>Save file</source>
        <translation>Lưu vào tập ti</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="193"/>
        <source>This calendar cannot be deleted. Delete all calendar content instead?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="201"/>
        <source>Delete this calendar and its events, tasks and notes?</source>
        <translation>Xóa phần lịch này và các sự kiện, tác vụ, ghi chú kèm theo?</translation>
    </message>
</context>
<context>
    <name>CalendarPickDialog</name>
    <message>
        <location filename="../CalendarPickDialog.ui" line="6"/>
        <source>Calendar</source>
        <translation>Lịch</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigDialog</name>
    <message>
        <location filename="../settings/CalendarsConfigDialog.ui" line="6"/>
        <source>Edit calendars</source>
        <translation>Chỉnh sửa lịch</translation>
    </message>
    <message>
        <location filename="../settings/CalendarsConfigDialog.cpp" line="27"/>
        <source>New</source>
        <translation>Tạo mới</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigSelector</name>
    <message numerus="yes">
        <location filename="../settings/CalendarsConfigSelector.cpp" line="16"/>
        <source>%n visible</source>
        <translation>
            <numerusform>%n hiển thị</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ChangeManager</name>
    <message>
        <location filename="../ChangeManager.cpp" line="239"/>
        <source>Delete event?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="242"/>
        <source>Delete task?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="245"/>
        <source>Delete note?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="248"/>
        <source>Delete component?</source>
        <translation>Xóa thành phần?</translation>
    </message>
</context>
<context>
    <name>ColorPickDialog</name>
    <message>
        <location filename="../ColorPickDialog.ui" line="6"/>
        <source>Color</source>
        <translation>Màu sắc</translation>
    </message>
    <message>
        <location filename="../ColorPickDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Hoàn tất</translation>
    </message>
</context>
<context>
    <name>ComponentEditDialog</name>
    <message>
        <location filename="../ComponentEditDialog.h" line="22"/>
        <source>Save</source>
        <translation>Lưu lại</translation>
    </message>
    <message>
        <location filename="../ComponentEditDialog.h" line="29"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>ComponentListDelegate</name>
    <message>
        <location filename="../ComponentListDelegate.h" line="80"/>
        <source>All
day</source>
        <translation>Tất cả
ngày</translation>
    </message>
</context>
<context>
    <name>ComponentListWidget</name>
    <message>
        <location filename="../ComponentListWidget.cpp" line="71"/>
        <source>Edit</source>
        <translation>Chỉnh sửa</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="72"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="73"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>ComponentWidget</name>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="183"/>
        <source>Edit</source>
        <translation>Chỉnh sửa</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="184"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="185"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>DateFormatDialog</name>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="6"/>
        <source>Date formats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="20"/>
        <source>Full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="37"/>
        <source>Partial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="72"/>
        <source>Day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="89"/>
        <source>Month</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.ui" line="106"/>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/DateFormatDialog.cpp" line="24"/>
        <source>Save</source>
        <translation>Lưu lại</translation>
    </message>
</context>
<context>
    <name>DatePickDialog</name>
    <message>
        <location filename="../DatePickDialog.cpp" line="27"/>
        <source>Done</source>
        <translation>Hoàn tất</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="181"/>
        <source>Week %1 (%2 - %3)</source>
        <translation>Tuần %1 (%2 - %3)</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.ui" line="6"/>
        <source>Select date</source>
        <translation>Chọn ngày</translation>
    </message>
</context>
<context>
    <name>DayNumberDialog</name>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="17"/>
        <source>Enter day number</source>
        <translation>Điền vào số ngày</translation>
    </message>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="24"/>
        <source>Add</source>
        <translation>Thêm vào</translation>
    </message>
</context>
<context>
    <name>DayWindow</name>
    <message>
        <location filename="../DayWindow.ui" line="35"/>
        <source>Previous day</source>
        <translation>Ngày trước đó</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="40"/>
        <source>Next day</source>
        <translation>Ngày tiếp theo</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="45"/>
        <source>Jump to today</source>
        <translation>Đi đến ngày hôm nay</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="50"/>
        <source>Jump to</source>
        <translation>Đi đến</translation>
    </message>
</context>
<context>
    <name>DetailedCalendarDelegate</name>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="30"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n sự kiệ</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="31"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n tác vụ</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="32"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n ghi chú</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>EventEditDialog</name>
    <message>
        <location filename="../EventEditDialog.ui" line="27"/>
        <source>Title</source>
        <translation>Tiêu đề</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="40"/>
        <source>Where</source>
        <translation>Tại</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="55"/>
        <source>All day</source>
        <translation>Tất cả ngày</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="64"/>
        <source>From</source>
        <translation>Từ</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="90"/>
        <source>To</source>
        <translation>Đến</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="118"/>
        <source>Time zone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="125"/>
        <source>Repeat</source>
        <translation>Lặp lại</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="135"/>
        <source>Calendar</source>
        <translation>Lịch</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="142"/>
        <source>Alarm</source>
        <translation>Báo thức</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="149"/>
        <source>Description</source>
        <translation>Mô tả</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="30"/>
        <source>Edit event</source>
        <translation>Chỉnh sửa sự kiện</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="33"/>
        <source>New event</source>
        <translation>Sự kiện mới</translation>
    </message>
</context>
<context>
    <name>EventWindow</name>
    <message>
        <location filename="../EventWindow.ui" line="6"/>
        <source>Event</source>
        <translation>Sự kiện</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="62"/>
        <source>To</source>
        <translation>Đến</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="86"/>
        <source>Repeat</source>
        <translation>Lặp lại</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="110"/>
        <source>Alarm</source>
        <translation>Báo thức</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="182"/>
        <source>Previous event</source>
        <translation>Sự kiện trước đó</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="187"/>
        <source>Next event</source>
        <translation>Sự kiện tiếp theo</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="192"/>
        <source>Edit event</source>
        <translation>Chỉnh sửa sự kiện</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="197"/>
        <source>Delete event</source>
        <translation>Xóa sự kiện</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="202"/>
        <source>Clone event</source>
        <translation>Đóng lại sự kiện</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="207"/>
        <source>Automatic links</source>
        <translation>Liên kết tự động</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="146"/>
        <source>From</source>
        <translation>Từ</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="146"/>
        <source>On</source>
        <translation>Vào</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="216"/>
        <location filename="../EventWindow.cpp" line="237"/>
        <source>No more events</source>
        <translation>Không có sự kiện nào</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="268"/>
        <source>Edit</source>
        <translation>Chỉnh sửa</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="269"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="270"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="../ImportDialog.ui" line="6"/>
        <source>Select calendar</source>
        <translation>Chọn lịch</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="44"/>
        <source>Import</source>
        <translation>Nhập dữ liệu</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="50"/>
        <source>New calendar</source>
        <translation>Tạo lịch mới</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="77"/>
        <source>Importing aborted</source>
        <translation>Bỏ qua thao tác nhập dữ liệu</translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="112"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n sự kiệ</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="113"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n tác vụ</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../ImportDialog.cpp" line="114"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n ghi chú</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="126"/>
        <location filename="../ImportDialog.cpp" line="194"/>
        <source>Error occurred</source>
        <translation>Xảy ra lỗi</translation>
    </message>
    <message>
        <location filename="../ImportDialog.cpp" line="187"/>
        <source>Some items already in calendar</source>
        <translation>Đã có một vài đối tượng tồn tại trong lịch</translation>
    </message>
</context>
<context>
    <name>JournalEditDialog</name>
    <message>
        <location filename="../JournalEditDialog.ui" line="22"/>
        <source>Calendar</source>
        <translation>Lịch</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="21"/>
        <source>Edit note</source>
        <translation>Chỉnh sửa ghi chú</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="24"/>
        <source>New note</source>
        <translation>Ghi chú mới</translation>
    </message>
</context>
<context>
    <name>JournalsPlug</name>
    <message>
        <location filename="../JournalsPlug.cpp" line="28"/>
        <source>New note</source>
        <translation>Ghi chú mới</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="47"/>
        <source>Notes</source>
        <translation>Các ghi chú</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="124"/>
        <source>Edit</source>
        <translation>Chỉnh sửa</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="125"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="126"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="63"/>
        <source>Month</source>
        <translation>Tháng</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="64"/>
        <source>Week</source>
        <translation>Tuần</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="65"/>
        <source>Agenda</source>
        <translation>Tổ chức</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="66"/>
        <source>Tasks</source>
        <translation>Các tác vụ</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="67"/>
        <source>Notes</source>
        <translation>Các ghi chú</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="68"/>
        <source>Settings</source>
        <translation>Thiết lập</translation>
    </message>
</context>
<context>
    <name>MonthPlug</name>
    <message>
        <location filename="../month/MonthPlug.cpp" line="60"/>
        <source>Previous month</source>
        <translation>Tháng trước đó</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="61"/>
        <source>Next month</source>
        <translation>Tháng tiếp theo</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="62"/>
        <source>Jump to today</source>
        <translation>Đi đến ngày</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="63"/>
        <source>Jump to</source>
        <translation>Đi đến</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="64"/>
        <source>New event</source>
        <translation>Sự kiện mới</translation>
    </message>
</context>
<context>
    <name>NewComponentWidget</name>
    <message>
        <location filename="../NewComponentWidget.h" line="24"/>
        <source>New event</source>
        <translation>Sự kiện mới</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../CWrapper.h" line="59"/>
        <source>Private</source>
        <translation>Riêng Tư</translation>
    </message>
    <message>
        <location filename="../CWrapper.h" line="61"/>
        <source>Birthdays</source>
        <translation>Sinh Nhật</translation>
    </message>
</context>
<context>
    <name>RecurrencePickDialog</name>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="6"/>
        <source>Recurrence</source>
        <translation>Sự lặp lại</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="24"/>
        <source>Repeat</source>
        <translation>Lặp lại</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="34"/>
        <source>View</source>
        <translation>Hiển thị</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="55"/>
        <source>Frequency</source>
        <translation>Chu kỳ</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
        <source>Daily</source>
        <translation>Mỗi ngày</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
        <source>Weekly</source>
        <translation>Mỗi tuần</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
        <source>Monthly</source>
        <translation>Mỗi tháng</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="81"/>
        <source>Yearly</source>
        <translation>Mỗi năm</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="89"/>
        <source>Interval</source>
        <translation>Khoảng thời gian</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
        <source>Forever</source>
        <translation>Mãi mãi</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
        <source>Until</source>
        <translation>Cho đến khi</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="123"/>
        <source>Count</source>
        <translation>Số lượng</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="188"/>
        <source>Week start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.cpp" line="36"/>
        <source>Done</source>
        <translation>Hoàn tất</translation>
    </message>
</context>
<context>
    <name>RecurrencePickSelector</name>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="37"/>
        <source>Never</source>
        <translation>Không bao giờ</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="39"/>
        <source>External</source>
        <translation>Phần bổ sung</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="41"/>
        <source>Every day</source>
        <translation>Mỗi ngày</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="43"/>
        <source>Every workday</source>
        <translation>Mỗi tuần làm việc</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="45"/>
        <source>Every week</source>
        <translation>Mỗi tuần</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="47"/>
        <source>Every month</source>
        <translation>Mỗi tháng</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="49"/>
        <source>Every year</source>
        <translation>Mỗi năm</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="51"/>
        <source>Complex</source>
        <translation>Nâng cao</translation>
    </message>
</context>
<context>
    <name>RulePickDialog</name>
    <message>
        <location filename="../recurrence/RulePickDialog.ui" line="6"/>
        <source>Select rule</source>
        <translation>Chọn lựa quy tắc</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="16"/>
        <source>New</source>
        <translation>Tạo mới</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="17"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <location filename="../recurrence/RulePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Hoàn tất</translation>
    </message>
</context>
<context>
    <name>RulePickSelector</name>
    <message>
        <location filename="../recurrence/RulePickSelector.cpp" line="14"/>
        <source>Rule %1 of %2</source>
        <translation>Quy tắc %1 của %2</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="6"/>
        <source>Settings</source>
        <translation>Thiết lập</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="31"/>
        <source>Edit calendars</source>
        <translation>Chỉnh sửa lịch</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="41"/>
        <source>Alarm tone</source>
        <translation>Nhạc báo thức</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="51"/>
        <source>Delete events</source>
        <translation>Xóa các sự kiện</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="61"/>
        <source>Delete tasks</source>
        <translation>Xóa các tác vụ</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="71"/>
        <source>First day of week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="81"/>
        <source>Editable time zones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="88"/>
        <source>Date formats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="19"/>
        <source>Save</source>
        <translation>Lưu lại</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="66"/>
        <source>Never</source>
        <translation>Không bao giờ</translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="68"/>
        <location filename="../settings/SettingsDialog.cpp" line="70"/>
        <source>Older than %n week(s)</source>
        <translation>
            <numerusform>Cũ hơn %n tuần</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="72"/>
        <source>Older than %n month(s)</source>
        <translation>
            <numerusform>Cũ hơn %n tháng</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="74"/>
        <source>Older than %n year(s)</source>
        <translation>
            <numerusform>Cũ hơn %n năm</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TodoEditDialog</name>
    <message>
        <location filename="../TodoEditDialog.ui" line="28"/>
        <source>Done</source>
        <translation>Hoàn tất</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="35"/>
        <source>Date</source>
        <translation>Ngày tháng</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="42"/>
        <source>Time zone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="49"/>
        <source>Calendar</source>
        <translation>Lịch</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="56"/>
        <source>Alarm</source>
        <translation>Báo thức</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="63"/>
        <source>Description</source>
        <translation>Mô tả</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="28"/>
        <source>Edit task</source>
        <translation>Chỉnh sửa tác vụ</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="31"/>
        <source>New task</source>
        <translation>Tác vụ mới</translation>
    </message>
</context>
<context>
    <name>TodoWindow</name>
    <message>
        <location filename="../TodoWindow.ui" line="6"/>
        <source>Task</source>
        <translation>Tác vụ</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="41"/>
        <source>Done</source>
        <translation>Hoàn tất</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="50"/>
        <source>Due</source>
        <translation>Cho đến</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="80"/>
        <source>Alarm</source>
        <translation>Báo thức</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="169"/>
        <source>Edit task</source>
        <translation>Chỉnh sửa tác vụ</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="174"/>
        <source>Delete task</source>
        <translation>Xóa tác vụ</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="179"/>
        <source>Clone task</source>
        <translation>Sao y tác vụ</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="184"/>
        <source>Automatic links</source>
        <translation>Liên kết tự động</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="171"/>
        <source>Edit</source>
        <translation>Chỉnh sửa</translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="172"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodoWindow.cpp" line="173"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>TodosPlug</name>
    <message>
        <location filename="../TodosPlug.cpp" line="34"/>
        <location filename="../TodosPlug.cpp" line="329"/>
        <source>New task</source>
        <translation>Tác vụ mới</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="41"/>
        <source>Hide completed</source>
        <translation>Đã hoàn tất thao tác ẩn</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="42"/>
        <source>Group by calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="43"/>
        <source>Delete completed</source>
        <translation>Đã hoàn tất thao tác xóa</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="71"/>
        <source>Tasks</source>
        <translation>Các tác vụ</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="332"/>
        <source>Edit</source>
        <translation>Chỉnh sửa</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="333"/>
        <source>Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="334"/>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="379"/>
        <source>Delete completed tasks from all calendars?</source>
        <translation>Xóa các tác vụ đã hoàn tất từ mọi phần lịch?</translation>
    </message>
</context>
<context>
    <name>TunePickDialog</name>
    <message>
        <location filename="../settings/TunePickDialog.ui" line="6"/>
        <source>Choose alarm tone</source>
        <translation>Chọn âm báo thức</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="17"/>
        <source>More</source>
        <translation>Thêm thông tin</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="18"/>
        <source>Done</source>
        <translation>Hoàn tất</translation>
    </message>
    <message>
        <location filename="../settings/TunePickDialog.cpp" line="67"/>
        <source>Add alarm tone</source>
        <translation>Thêm âm báo thức</translation>
    </message>
</context>
<context>
    <name>WeekButton</name>
    <message>
        <location filename="../month/WeekButton.cpp" line="33"/>
        <source>w%1</source>
        <translation>w%1</translation>
    </message>
</context>
<context>
    <name>WeekPlug</name>
    <message>
        <location filename="../week/WeekPlug.cpp" line="43"/>
        <source>Previous week</source>
        <translation>Tuần trước đó</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="44"/>
        <source>Next week</source>
        <translation>Tuần tiếp theo</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="45"/>
        <source>Jump to today</source>
        <translation>Đi đến ngày hôm nay</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="46"/>
        <source>Jump to</source>
        <translation>Đi đến</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="47"/>
        <source>New event</source>
        <translation>Sự kiện mới</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="70"/>
        <source>Week %1 (%2)</source>
        <translation>Tuần %1 (%2)</translation>
    </message>
</context>
<context>
    <name>WeekWidget</name>
    <message>
        <location filename="../week/WeekWidget.cpp" line="364"/>
        <source>All day</source>
        <translation>Tất cả ngày</translation>
    </message>
</context>
<context>
    <name>ZonePickDialog</name>
    <message>
        <location filename="../ZonePickDialog.ui" line="6"/>
        <source>Time zone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ZonePickDialog.ui" line="39"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ZonePickDialog.cpp" line="79"/>
        <source>Current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
